package com.hncy.sjdz.constant.enums;

import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

import java.util.Objects;

/**
 * ResponsibilitySystemTypeEnum 责任类型
 * <p>
 * Enum("name","value")
 * <p>
 * ----------------------------------
 * <p>
 * OPERATION("运营", "1")
 * <p>
 * DISPOSE("处置", "2")
 * <p>
 * PATROL("巡查", "3")
 * <p>
 * SUPERVISE("监督", "4")
 *
 * @Author: lm
 * @Date: 2023/11/30
 */
@Getter
@RequiredArgsConstructor
public enum ResponsibilitySystemTypeEnum {

    /**
     * 运营 v:"1"
     */
    OPERATION("运营责任", "1"),
    /**
     * 处置 v:"2"
     */
    DISPOSE("处置责任", "2"),
    /**
     * 巡查 v:"3"
     */
    PATROL("巡查责任", "3"),
    /**
     * 监督 v:"4"
     */
    SUPERVISE("监督责任", "4");

    private final String name;

    @JsonValue
    private final String value;

    public static String getName(String value) {
        ResponsibilitySystemTypeEnum[] enums = ResponsibilitySystemTypeEnum.values();
        for (ResponsibilitySystemTypeEnum nowEnum : enums) {
            if (nowEnum.getValue().equals(value)) {
                return nowEnum.getName();
            }
        }
        return "/";
    }

    public static String convertName(ResponsibilitySystemTypeEnum enumObj) {
        return Objects.isNull(enumObj) ? "/" : enumObj.getName();
    }

}