package com.hncy.sjdz.util;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.date.LocalDateTimeUtil;

import java.text.SimpleDateFormat;
import java.time.*;
import java.time.format.DateTimeFormatter;
import java.time.temporal.IsoFields;
import java.time.temporal.TemporalAdjuster;
import java.time.temporal.TemporalAdjusters;
import java.time.temporal.WeekFields;
import java.util.*;
import java.util.concurrent.CopyOnWriteArrayList;

/**
 * <p>
 *
 * </p>
 *
 * @author liyl
 * @since 2024/1/22 11:39
 */
public class TimeUtils {

    /**
     * 根据年月获取月初第一天日期
     * @param year
     * @param month
     * @return
     */
    public static String getFirstDay(int year, int month, String format) {
        Calendar cale = Calendar.getInstance();

        cale.set(Calendar.YEAR, year); // 赋值年份
        cale.set(Calendar.MONTH, month - 1);// 赋值月份
        int lastDay = cale.getActualMinimum(Calendar.DAY_OF_MONTH);// 获取月最大天数
        cale.set(Calendar.DAY_OF_MONTH, lastDay);// 设置日历中月份的最大天数
        SimpleDateFormat sdf = new SimpleDateFormat(format);// 格式化日期yyyy-MM-dd
        return sdf.format(cale.getTime());
    }

    /**
     * 根据年月获取月末最后一天日期
     * @param year
     * @param month
     * @return
     */
    public static String getLastDay(int year, int month, String format) {
        Calendar cale = Calendar.getInstance();

        cale.set(Calendar.YEAR, year);// 赋值年份
        cale.set(Calendar.MONTH, month - 1);// 赋值月份
        int lastDay = cale.getActualMaximum(Calendar.DAY_OF_MONTH);// 获取月最大天数
        cale.set(Calendar.DAY_OF_MONTH, lastDay);// 设置日历中月份的最大天数
        SimpleDateFormat sdf = new SimpleDateFormat(format); // 格式化日期yyyy-MM-dd
        String lastDayOfMonth = sdf.format(cale.getTime());
        return lastDayOfMonth;
    }

    /**
     * 获取某年最后一天日期
     * @param year 年份
     * @return Date
     */
    public static String getYearLast(int year) {
        Calendar calendar = Calendar.getInstance();
        calendar.clear();
        calendar.set(Calendar.YEAR, year);
        calendar.roll(Calendar.DAY_OF_YEAR, -1);
        return new SimpleDateFormat("yyyy-MM-dd").format(calendar.getTime());
    }

    public Date getDayEnd(Date time) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(time);
        // 把小时置为23
        cal.set(Calendar.HOUR_OF_DAY, 23);
        // 把分钟置为59
        cal.set(Calendar.MINUTE, 59);
        // 把秒置为59
        cal.set(Calendar.SECOND, 59);
        // 把毫秒置为999
        cal.set(Calendar.MILLISECOND, 999);
        return cal.getTime();
    }

    /**
     * 获取年第一天
     * @param year
     * @return
     */
    public static String getYearFirst(int year) {
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, Calendar.JANUARY);
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.set(Calendar.HOUR_OF_DAY, 0);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        Date firstDayOfYear = calendar.getTime();
        return DateUtil.format(firstDayOfYear, "yyyy-MM-dd");
    }

    /**
     * 根据年获取年最后一天时间
     * @param year
     * @return
     */
    public static String getYearLastDay(int year) {
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, calendar.getActualMaximum(Calendar.MONTH));
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getActualMaximum(Calendar.DAY_OF_MONTH));
        calendar.set(Calendar.HOUR_OF_DAY, 23);
        calendar.set(Calendar.MINUTE, 59);
        calendar.set(Calendar.SECOND, 59);
        Date firstDayOfYear = calendar.getTime();
        return DateUtil.format(firstDayOfYear, "yyyy-MM-dd");
    }

    /**
     * 根据年，周获取
     * @param year
     * @param week
     * @return
     */
    public static String getWeek(int year, int week) {
        TimeZone.setDefault(TimeZone.getTimeZone("GMT+8"));
        Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT+8"));
        cal.clear();
        cal.set(Calendar.YEAR, year);
        cal.set(Calendar.WEEK_OF_YEAR, week);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);
        String date = format(cal.getTime());
        cal.set(Calendar.DAY_OF_WEEK, Calendar.TUESDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.WEDNESDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.THURSDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.FRIDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.SATURDAY);
        cal.add(Calendar.DATE, 1);
        date = date + "-" + (format(cal.getTime()));
        return date;
    }

    /**
     * 根据年周 获取日期范围 形如 yyyy-MM-dd&yyyy-MM-dd
     * @param year
     * @param week
     * @return
     */
    public static String getWeekyyyyMMdd(int year, int week) {
        TimeZone.setDefault(TimeZone.getTimeZone("GMT+8"));
        Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT+8"));
        cal.clear();
        cal.set(Calendar.YEAR, year);
        cal.set(Calendar.WEEK_OF_YEAR, week);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);
        String date = DateUtil.format(cal.getTime(), "yyyy-MM-dd");
        cal.set(Calendar.DAY_OF_WEEK, Calendar.TUESDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.WEDNESDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.THURSDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.FRIDAY);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.SATURDAY);
        cal.add(Calendar.DATE, 1);
        date = date + "&" + (DateUtil.format(cal.getTime(), "yyyy-MM-dd"));
        return date;
    }

    public static String format(Date date) {
        if (date != null) {
            SimpleDateFormat df = new SimpleDateFormat("yyyy年MM月dd日");
            return df.format(date);
        }
        return null;
    }

    /**
     * 获取昨日的日期
     * @param localDate
     * @return
     */
    public static String getYesterday(LocalDate localDate) {

        // 减去一天
        LocalDate yesterday = localDate.minusDays(1);
        return yesterday.toString();
    }

    /**
     * 获取上一周周数
     * @param year
     * @param week
     * @return
     */
    public static String getLastWeek(String year, String week) {
        if (week.equals("1")) {
            return Integer.parseInt(year) - 1 + "-52";
        }
        else {
            return year + "-" + String.valueOf(Integer.parseInt(week) - 1);
        }
    }

    /**
     * 获取上一个月
     * @param yearMonth
     * @return
     */
    public static String getLastMonth(String yearMonth) {
        String[] parts = yearMonth.split("-");
        int year = Integer.parseInt(parts[0]);
        int month = Integer.parseInt(parts[1]);
        YearMonth currentMonth = YearMonth.of(year, month);
        // 减去一个月
        YearMonth lastMonth = currentMonth.minusMonths(1);
        // 将结果格式化为"yyyy-MM"格式的字符串
        String lastMonthString = lastMonth.format(DateTimeFormatter.ofPattern("yyyy-MM"));
        return lastMonthString;
    }

    /**
     * 获取上一季度
     * @param year
     * @param quarter
     * @return
     */
    public static String getLastQuarter(String year, String quarter) {
        if (quarter.equals("1")) {
            return Integer.parseInt(year) - 1 + "-4";
        }
        else {
            return year + "-" + (Integer.parseInt(quarter) - 1);
        }
    }

    /**
     * 根据年、周、周几获取日期
     * @param year
     * @param weeks
     * @param week
     * @return
     */
    public static String getDayByYearWeeks(int year, int weeks, Long week) {
        WeekFields weekFields = WeekFields.ISO;
        LocalDate now = LocalDate.now();
        // 输入你想要的年份和周数
        LocalDate localDate = now.withYear(year).with(weekFields.weekOfYear(), weeks);
        // 以周一为每周的第一天
        // 周一（第一天）
        LocalDate localDate1 = localDate.with(weekFields.dayOfWeek(), week);
        return localDate1.toString();
    }

    /**
     * 根据 日期获取星期
     * @param day
     * @return
     */
    public static String getWeekByDay(String day) {
        Date date = DateUtil.parse(day, "yyyy-MM-dd");
        SimpleDateFormat dateFm = new SimpleDateFormat("EEEE");
        return dateFm.format(date);
    }

    /**
     * 获取月的第一天 2023-08
     * @param month
     * @return
     */
    public static String getMonthFirst(String month) {
        // 获取当前日期
        LocalDate currentDate = LocalDateTimeUtil.parseDate(month, "yyyy-MM");
        // 获取当前月份的第一天
        LocalDate firstDayOfMonth = currentDate.withDayOfMonth(1);
        return firstDayOfMonth.toString();
    }

    /**
     * 获取月的最后一天
     * @param month
     * @return
     */
    public static String getMonthEnd(String month) {
        // 获取当前日期
        LocalDate currentDate = LocalDateTimeUtil.parseDate(month, "yyyy-MM");
        // 获取当前月份的最后一天
        YearMonth currentYearMonth = YearMonth.from(currentDate);

        LocalDate lastDayOfMonth = currentYearMonth.atEndOfMonth();
        return lastDayOfMonth.toString();
    }

    /**
     * 根据年季度获取月份
     * @param year
     * @param quarter
     * @return
     */
    public static List<String> getMonthByQuarter(String year, String quarter) {
        List<String> months = new ArrayList<>();
        if ("1".equals(quarter)) {
            months.add(year + "-01");
            months.add(year + "-02");
            months.add(year + "-03");
        }
        else if ("2".equals(quarter)) {
            months.add(year + "-04");
            months.add(year + "-05");
            months.add(year + "-06");
        }
        else if ("3".equals(quarter)) {
            months.add(year + "-07");
            months.add(year + "-08");
            months.add(year + "-09");
        }
        else if ("4".equals(quarter)) {
            months.add(year + "-10");
            months.add(year + "-11");
            months.add(year + "-12");
        }
        return months;
    }

    /**
     * 获取上一个小时开始的时间
     * @return
     */
    public static LocalDateTime getLastStartHour() {

        // 创建一个Calendar实例
        Calendar calendar = Calendar.getInstance();

        // 获取当前时间的小时
        int hour = calendar.get(Calendar.HOUR_OF_DAY);

        // 设置上一个小时的开始时间
        calendar.set(Calendar.HOUR_OF_DAY, hour - 1);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        return LocalDateTimeUtil.of(calendar.getTime());

    }

    /**
     * 获取上一个小时最后的时间
     * @return
     */
    public static LocalDateTime getLastEndHour() {
        // 创建一个Calendar实例
        Calendar calendar = Calendar.getInstance();
        // 获取当前时间的小时
        int hour = calendar.get(Calendar.HOUR_OF_DAY);
        // 设置上一个小时的结束时间
        calendar.set(Calendar.HOUR_OF_DAY, hour);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        return LocalDateTimeUtil.of(calendar.getTime());
    }

    /**
     * 获取昨天的日期
     * @return
     */
    public static LocalDate getYesterDay() {
        LocalDate today = LocalDate.now(); // 获取当前日期
        LocalDate yesterday = today.minus(Period.ofDays(1)); // 获取昨天的日期
        return yesterday;
    }

    /**
     * 根据传入时间 获取上周一时间
     * @param nowTime
     * @return
     */
    public static LocalDate getLastWeekMonday(long nowTime) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(new Date(nowTime));
        if (1 == cal.get(Calendar.DAY_OF_WEEK)) {// 判断当前日期是否为周末，因为周末是本周第一天，如果不向后推迟一天的到的将是下周一的零点，而不是本周周一零点
            cal.add(Calendar.DATE, -1);
        }
        cal.add(Calendar.DAY_OF_MONTH, -7);// 时间减去7天
        cal.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);// Calendar.MONDAY 这个是周一的意思
        // 想获取周几就更换这个
        return LocalDateTimeUtil.of(cal.getTime()).toLocalDate();
    }

    /**
     * 根据传入时间 获取上周周天时间
     * @param nowTime
     * @return
     */
    public static LocalDate getLastWeekSunday(long nowTime) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(new Date(nowTime));
        if (1 == cal.get(Calendar.DAY_OF_WEEK)) {// 判断当前日期是否为周末，因为周末是本周第一天，如果不向后推迟一天的到的将是下周一的零点，而不是本周周一零点
            cal.add(Calendar.DATE, -1);
        }
        cal.set(Calendar.DAY_OF_WEEK, Calendar.SUNDAY);// Calendar.SUNDAY 周天想获取周几就更换这个
        return LocalDateTimeUtil.of(cal.getTime()).toLocalDate();
    }

    /**
     * 根据传入时间 获取上月第一天的一时间
     * @param nowTime
     * @return
     */
    public static LocalDate getLastMonthFirstDate(long nowTime) {
        Calendar cal = Calendar.getInstance();
        // 设置为指定日期
        cal.setTime(new Date(nowTime));
        // 指定日期月份减去一
        cal.add(Calendar.MONTH, -1);
        // 指定日期月份减去一后的 获取第一天
        cal.set(Calendar.DAY_OF_MONTH, cal.getActualMinimum(Calendar.DAY_OF_MONTH));
        // 获取最终的时间
        return LocalDateTimeUtil.of(cal.getTime()).toLocalDate();
    }

    /**
     * 根据传入时间 获取上月最后一天一时间
     * @param nowTime
     * @return
     */
    public static LocalDate getLastMonthEndDate(long nowTime) {
        Calendar cal = Calendar.getInstance();
        // 设置为指定日期
        cal.setTime(new Date(nowTime));
        // 指定日期月份减去一
        cal.add(Calendar.MONTH, -1);
        // 指定日期月份减去一后的 最大天数
        cal.set(Calendar.DATE, cal.getActualMaximum(Calendar.DATE));
        // 获取最终的时间
        return LocalDateTimeUtil.of(cal.getTime()).toLocalDate();
    }

    /**
     * 根据日期获取周数
     * @param date
     * @return
     */
    public static List<String> getWeekNumber(String date) {
        List<String> list = new CopyOnWriteArrayList<>();
        Calendar calendar = Calendar.getInstance();
        calendar.setFirstDayOfWeek(Calendar.MONDAY);
        calendar.setTime(DateUtil.parseDate(date));
        list.add(String.valueOf(calendar.get(Calendar.YEAR)));
        list.add(String.valueOf(calendar.get(Calendar.WEEK_OF_YEAR)));
        return list;
    }

    /**
     * 根据日期获取上一季度月份
     * @param month
     * @return
     */
    public static String getLastFirstQuarterByMonth(LocalDate month) {
        // 返回形如 2023-01&2023-03
        // 获取当前季度
        int currentQuarter = month.get(IsoFields.QUARTER_OF_YEAR);
        if (currentQuarter == 1) {
            return (month.getYear() - 1) + "-10&" + ((month.getYear() - 1)) + "-12";
        }
        else if (currentQuarter == 2) {
            return (month.getYear()) + "-01&" + (month.getYear()) + "-03";
        }
        else if (currentQuarter == 3) {
            return (month.getYear()) + "-04&" + (month.getYear()) + "-06";
        }
        else if (currentQuarter == 4) {
            return (month.getYear()) + "-07&" + (month.getYear()) + "-09";
        }
        return "";
    }

    public static List<String> getDayRangeDate(String startTime, String endTime) {
        List<String> date = new ArrayList<>();
        LocalDate startDate = LocalDateTimeUtil.parseDate(startTime);
        LocalDate endDate = LocalDateTimeUtil.parseDate(endTime);

        LocalDate currentDate = startDate;
        while (currentDate.isBefore(endDate) || currentDate.isEqual(endDate)) {
            date.add(LocalDateTimeUtil.format(currentDate, "yyyy-MM-dd"));
            currentDate = currentDate.plusDays(1); // 增加一天，处理下一个日期
        }
        return date;
    }

    /**
     * 根据月份获取季度
     * @param month
     * @return
     */
    public static String getQuarter(String month) {
        return LocalDateTimeUtil.parseDate(month).getYear() + "-"
                + LocalDateTimeUtil.parseDate(month).get(IsoFields.QUARTER_OF_YEAR);
    }

    /**
     * 根据年获取年内所有月份
     * @param yearNum
     * @return
     */
    public static List<String> getYearMonth(int yearNum) {
        Year year = Year.of(yearNum);
        List<String> months = new ArrayList<>();
        for (int i = 1; i <= 12; i++) {
            months.add(year.atMonth(i).toString());
        }
        return months;
    }

    /**
     * 获取两个日期之间的所有月份 (年月)
     * @param startTime
     * @param endTime
     * @return：list
     */
    public static List<String> getMonthBetweenDate(LocalDateTime startTime, LocalDateTime endTime) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
        // 声明保存日期集合
        List<String> list = new ArrayList<>();
        try {
            // 转化成日期类型
            Date startDate = DateUtil.date(startTime);
            Date endDate = DateUtil.date(endTime);

            // 用Calendar 进行日期比较判断
            Calendar calendar = Calendar.getInstance();
            while (startDate.getTime() <= endDate.getTime()) {

                // 把日期添加到集合
                list.add(sdf.format(startDate));

                // 设置日期
                calendar.setTime(startDate);

                // 把月数增加 1
                calendar.add(Calendar.MONTH, 1);

                // 获取增加后的日期
                startDate = calendar.getTime();
            }
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 输入年月获取月份内所有日期
     * @param year
     * @param month
     * @return
     */
    public static List<LocalDate> getMonthDayList(int year, int month) {
        YearMonth yearMonthObject = YearMonth.of(year, month);
        int daysInMonth = yearMonthObject.lengthOfMonth();

        List<LocalDate> allDatesInMonth = new ArrayList<>();
        for (int day = 1; day <= daysInMonth; day++) {
            LocalDate date = LocalDate.of(year, month, day);
            allDatesInMonth.add(date);
        }
        return allDatesInMonth;
    }

    public static List<String> getDayTimeList(String dateString) {
        // 将字符串解析为 LocalDate
        LocalDateTime date = LocalDateTime.parse(dateString + "T00:00:00");

        DateTimeFormatter timeFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

        List<String> timeRanges = new ArrayList<>();

        // 获取某日每个小时的开始时间和结束时间
        for (int hour = 0; hour < 24; hour++) {
            LocalDateTime startHour = date.plusHours(hour);
            LocalDateTime endHour = startHour.plusHours(1).minusSeconds(1); // 结束时间为开始时间加一小时减一秒

            String startTimeStr = startHour.format(timeFormatter);
            String endTimeStr = endHour.format(timeFormatter);

            timeRanges.add(startTimeStr + "&" + endTimeStr);
        }
        return timeRanges;
    }

    /**
     * 根据yyyy-MM,获取前limit个月月份
     * @param month
     * @param limit
     * @return
     */
    public static List<String> getInRecentMonths(String month, int limit) {
        List<String> months = new ArrayList<>();
        // 解析输入的月份
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        YearMonth yearMonth = YearMonth.parse(month, formatter);

        // 获取当前月份及前4个月的月份
        for (int i = 0; i < limit; i++) {
            String currentMonth = yearMonth.format(formatter);
            months.add(currentMonth);
            // 切换到前一个月
            yearMonth = yearMonth.minusMonths(1);
        }
        return months;
    }

    /**
     * 根据年、周 获取近limit周周数
     * @param year
     * @param week
     * @param limit
     * @return
     */
    public static List<String> getInRecentWeeks(int year, int week, int limit) {
        List<String> weeks = new ArrayList<>();
        // 设置Locale为默认值，你也可以根据需要设置不同的Locale
        WeekFields weekFields = WeekFields.of(Locale.getDefault());

        // 获取指定周的第一天
        LocalDate inputDate = LocalDate.of(year, 1, 1)
            .with(TemporalAdjusters.previousOrSame(DayOfWeek.MONDAY))
            .plusWeeks(week - 1);
        // 获取前6周的年份和周数
        for (int i = 0; i < limit; i++) {
            int currentYear = inputDate.getYear();
            int currentWeek = inputDate.get(weekFields.weekOfWeekBasedYear());
            weeks.add(currentYear + "-" + currentWeek);
            // 切换到前一周
            inputDate = inputDate.minusWeeks(1);
        }
        return weeks;
    }

    public static List<String> getInRecentDay(String day, int limit) {
        List<String> days = new ArrayList<>();
        // 解析输入的日期
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        LocalDate currentDate = LocalDate.parse(day, formatter);
        // 获取近5日的日期
        for (int i = 0; i < limit; i++) {
            days.add(currentDate.format(formatter));
            // 切换到前一天
            currentDate = currentDate.minusDays(1);
        }
        return days;
    }

    /**
     * 获取最近5年的
     * @param year
     * @param limit
     * @return
     */
    public static List<String> getInRecentYear(String year, int limit) {
        List<String> years = new ArrayList<>();
        // 解析输入的年份
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy");
        int currentYear = Integer.parseInt(year);
        LocalDate currentDate = LocalDate.of(currentYear, 1, 1);
        // 获取最近5年的日期
        for (int i = 0; i < limit; i++) {
            years.add(currentDate.format(formatter));
            // 切换到前一年
            currentDate = currentDate.minusYears(1);
        }
        return years;
    }

	public static List<String> getWeekDay(){
		// 获取当前日期
		LocalDate today = LocalDate.now();

		// 获取本周的第一天（周一）和最后一天（周日）
		LocalDate startOfWeek = today.with((TemporalAdjuster) DayOfWeek.MONDAY.adjustInto(today.minusDays(today.getDayOfWeek().getValue() - 1)));
		LocalDate endOfWeek = today.with((TemporalAdjuster) DayOfWeek.SUNDAY.adjustInto(today));

		// 创建一个列表来存储本周的每一天
		List<String> weekDates = new ArrayList<>();

		// 遍历本周的每一天
		for (LocalDate date = startOfWeek; !date.isAfter(endOfWeek); date = date.plusDays(1)) {
			// 格式化日期并添加到列表中
			DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
			weekDates.add(date.format(formatter));
		}
		return weekDates;
	}

	public static List<String> getDayHours(){
		List<String> dayHours = new ArrayList<>();
		// 获取当前日期
		LocalDateTime todayStart = LocalDateTime.now().withHour(0).withMinute(0).withSecond(0).withNano(0);

		// 创建一个DateTimeFormatter来格式化日期时间
		DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH");

		// 遍历从00:00到23:00的每个小时
		for (int hour = 0; hour < 24; hour++) {
			// 创建表示当前小时的时间点
			LocalDateTime currentTime = todayStart.withHour(hour);

			// 格式化并打印
			String formattedTime = currentTime.format(formatter);
			dayHours.add(formattedTime);
		}
		return dayHours;
	}

}
