package com.hncy.sjdz.base.controller;


import com.hncy.sjdz.base.mapper.SafetyMonitoringObjectInfoMapper;
import com.hncy.sjdz.base.mapper.SafetyMonitoringRecordInfoMapper;
import com.hncy.sjdz.base.models.entity.SafetyMonitoringObjectInfo;
import com.hncy.sjdz.base.models.entity.SafetyMonitoringRecordInfo;
import com.hncy.sjdz.base.service.SafetyMonitoringObjectInfoService;
import com.hncy.sjdz.base.util.cdEncryption.DataEncryptionUtil;
import com.hncy4cloud.hncy.common.core.util.R;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.springframework.web.bind.annotation.GetMapping;

import javax.annotation.Resource;
import java.util.List;


/**
 * 监测对象表
 *
 * @author cp
 * @since 2024-11-07 15:23:28
 */
@RestController
@RequestMapping("/safetyMonitoringObjectInfo")
@Slf4j
public class SafetyMonitoringObjectInfoController {

	@Autowired
	private SafetyMonitoringObjectInfoService safetyMonitoringObjectInfoService;



	@Resource
	private SafetyMonitoringObjectInfoMapper safetyMonitoringObjectInfoMapper;

	@Resource
	private SafetyMonitoringRecordInfoMapper safetyMonitoringRecordInfoMapper;


	@Autowired(required = false)
	private DataEncryptionUtil dataEncryptionUtil;

	/**
	 * 统计各风险等级设施数
	 *
	 * @return
	 */
	@GetMapping("/statisticalRiskLevel")
	public R statisticalRiskLevel(@Parameter(name = "parentTypeCode", description = "监测对象类别父级code", required = false)
								  @RequestParam(name = "parentTypeCode", required = false) String parentTypeCode,
								  @Parameter(name = "areaCode", description = "地区code", required = false)
								  @RequestParam(name = "areaCode", required = false) String areaCode) {

		return safetyMonitoringObjectInfoService.statisticalRiskLevel(parentTypeCode,areaCode);
	}

	/**
	 * 统计当前风险预警设施类型
	 *
	 * @return
	 */
	@GetMapping("/statisticalType")
	public R statisticalType() {

		return safetyMonitoringObjectInfoService.statisticalType();
	}

	/**
	 * 风险源点位
	 *
	 * @return
	 */
	@GetMapping("/findListForMap")
	public R findListForMap(@Parameter(name = "parentTypeCode", description = "监测对象类别父级code", required = false)
							@RequestParam(name = "parentTypeCode", required = false) String parentTypeCode,
							@Parameter(name = "monitoringObjectTypeCodeList", description = "监测对象类別编码集合", required = false)
							@RequestParam(name = "monitoringObjectTypeCodeList", required = false) String monitoringObjectTypeCodeList,
							@Parameter(name = "lat", description = "纬度", required = true)
							@RequestParam(name = "lat", required = false) String lat,
							@Parameter(name = "lon", description = "经度", required = true)
							@RequestParam(name = "lon", required = false) String lon,
							@Parameter(name = "distance", description = "距离", required = true)
							@RequestParam(name = "distance", required = false) String distance,
							@Parameter(name = "page", description = "页码", required = true, example = "1") @RequestParam(name = "page", defaultValue = "1") int page,
							@Parameter(name = "count", description = "每页条数", required = true, example = "10") @RequestParam(name = "count", defaultValue = "10") int count
							, @Parameter(name = "areaCode", description = "地区code", required = false)
								@RequestParam(name = "areaCode", required = false) String areaCode) {

		return safetyMonitoringObjectInfoService.findListForMap(parentTypeCode, monitoringObjectTypeCodeList,lat,lon,distance,areaCode);
	}


	/**
	 * 设施详情
	 *
	 * @return
	 */
	@GetMapping("/getInfo")
	public R getInfo(@Parameter(name = "id", description = "设施id", required = false)
					 @RequestParam(name = "id", required = false) String id) {
		List<SafetyMonitoringObjectInfo> list = safetyMonitoringObjectInfoMapper.listfifty();
		for (SafetyMonitoringObjectInfo   safetyMonitoringObjectInfo:    list){
			String str = dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getMonitoringObjectName());
			safetyMonitoringObjectInfo.setMonitoringObjectName(str);
		}

		return safetyMonitoringObjectInfoService.getInfo(id);
	}


	/**
	 * test
	 *
	 * @return
	 */
	@GetMapping("/test1")
	public R test1() {
		List<SafetyMonitoringObjectInfo> list = safetyMonitoringObjectInfoMapper.listfifty();

		for (SafetyMonitoringObjectInfo   safetyMonitoringObjectInfo:    list){

			if (dataEncryptionUtil!=null){
				String objectName = dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getMonitoringObjectName());
				safetyMonitoringObjectInfo.setMonitoringObjectName(objectName);

				String objectTypeName = dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getMonitoringObjectTypeName());
				safetyMonitoringObjectInfo.setMonitoringObjectTypeName(objectTypeName);

				String photos  = dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getPhotos());
				safetyMonitoringObjectInfo.setPhotos(photos);

				String position  = 	dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getPosition());
				safetyMonitoringObjectInfo.setPosition(position);

				String xpos  = 	dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getXPos());
				safetyMonitoringObjectInfo.setXPos(xpos);

				String ypos  = 	dataEncryptionUtil.encryptSM4(safetyMonitoringObjectInfo.getYPos());
				safetyMonitoringObjectInfo.setYPos(ypos);
			}
			safetyMonitoringObjectInfoMapper.updateById(safetyMonitoringObjectInfo);
			log.info("加密"+safetyMonitoringObjectInfo.getId());
		}

		return R.ok();
	}



	/**
	 * test
	 *
	 * @return
	 */
	@GetMapping("/test2")
	public R test2() {
		List<SafetyMonitoringRecordInfo> list = safetyMonitoringRecordInfoMapper.listfifty();

		for (SafetyMonitoringRecordInfo   safetyMonitoringRecordInfo:    list){
			if (dataEncryptionUtil!=null){
				String monitoringProject = dataEncryptionUtil.encryptSM4(safetyMonitoringRecordInfo.getMonitoringProject());
				safetyMonitoringRecordInfo.setMonitoringProject(monitoringProject);

				String monitoringValue = dataEncryptionUtil.encryptSM4(safetyMonitoringRecordInfo.getMonitoringValue());
				safetyMonitoringRecordInfo.setMonitoringValue(monitoringValue);

			}
			safetyMonitoringRecordInfoMapper.updateById(safetyMonitoringRecordInfo);
			log.info("加密"+safetyMonitoringRecordInfo.getId());
		}

		return R.ok();
	}
}