package com.hncy.sjdz.base.controller;


import com.hncy.sjdz.base.service.SafetyRiskEventInfoService;
import com.hncy4cloud.hncy.common.core.util.R;
import io.swagger.v3.oas.annotations.Parameter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.springframework.web.bind.annotation.GetMapping;


/**
 * 风险事件表
 *
 * @author cp
 * @since 2024-11-07 15:33:16
 */
@RestController
@RequestMapping("/safetyRiskEventInfo")
public class SafetyRiskEventInfoController {

	@Autowired
	private SafetyRiskEventInfoService safetyRiskEventInfoService;


	/**
	 * 统计今日预警，受理代办，处置回复数量
	 *
	 * @return
	 */
	@GetMapping("/statisticalEvent")
	public R statisticalEvent(@Parameter(name = "parentTypeCode", description = "监测对象类别父级code", required = false)
							  @RequestParam(name = "parentTypeCode", required = false) String parentTypeCode,
							  @Parameter(name = "areaCode", description = "地区code", required = false)
							  @RequestParam(name = "areaCode", required = false) String areaCode) {
		return safetyRiskEventInfoService.statisticalEvent(parentTypeCode, areaCode);
	}


	/**
	 * 事件分页列表
	 *
	 * @return
	 */
	@GetMapping("/eventPage")
	public R eventPage(@Parameter(name = "page", description = "页码", required = true, example = "1")
					   @RequestParam(name = "page", defaultValue = "1") int page,
					   @Parameter(name = "count", description = "每页条数", required = true, example = "10")
					   @RequestParam(name = "count", defaultValue = "10") int count, @Parameter(name = "parentTypeCode", description = "监测对象类别父级code", required = false)
					   @RequestParam(name = "parentTypeCode", required = false) String parentTypeCode,
					   @Parameter(name = "riskLevelCode", description = "风险等级", required = false)
					   @RequestParam(name = "riskLevelCode", required = false) String riskLevelCode,
					   @Parameter(name = "disposalStatus", description = "处置状态", required = false)
					   @RequestParam(name = "disposalStatus", required = false) String disposalStatus,
					   @Parameter(name = "source", description = "来源方式", required = false)
					   @RequestParam(name = "source", required = false) String source,
					   @Parameter(name = "areaCode", description = "地区code", required = false)
					   @RequestParam(name = "areaCode", required = false) String areaCode,
					   @Parameter(name = "dateType", description = "统计时间类型，month 近一月,today 本日", required = false)
						   @RequestParam(name = "dateType", required = false) String dateType) {
		return safetyRiskEventInfoService.eventPage(parentTypeCode, riskLevelCode, disposalStatus, source, areaCode,dateType);
	}


	/**
	 * 事件详情
	 *
	 * @return
	 */
	@GetMapping("/getInfo")
	public R getInfo(@Parameter(name = "riskId", description = "事件id", required = false)
					 @RequestParam(name = "riskId", required = false) String riskId) {
		return safetyRiskEventInfoService.getInfo(riskId);
	}


	/**
	 * 统计最近30天各级别数量
	 *
	 * @return
	 */
	@GetMapping("/statisticalMonth")
	public R statisticalMonth( @Parameter(name = "areaCode", description = "地区code", required = false)
								   @RequestParam(name = "areaCode", required = false) String areaCode) {
		return safetyRiskEventInfoService.statisticalMonth(areaCode);
	}


	/**
	 * 统计按区域
	 *
	 * @return
	 */
	@GetMapping("/statisticalArea")
	public R statisticalArea() {
		return safetyRiskEventInfoService.statisticalArea();
	}


	/**
	 * 统计按大小细类
	 *
	 * @return
	 */
	@GetMapping("/statisticalType")
	public R statisticalType(@Parameter(name = "type", description = "type:大类0，小类1，细类2", required = false)
								 @RequestParam(name = "type", required = false) String type) {
		return safetyRiskEventInfoService.statisticalType(type);
	}




	/**
	 * 事件点位
	 *
	 * @return
	 */
	@GetMapping("/findListForMap")
	public R findListForMap(@Parameter(name = "parentTypeCode", description = "监测对象类别父级code", required = false)
							@RequestParam(name = "parentTypeCode", required = false) String parentTypeCode,
							@Parameter(name = "monitoringObjectTypeCodeList", description = "监测对象类別编码集合", required = false)
							@RequestParam(name = "monitoringObjectTypeCodeList", required = false) String monitoringObjectTypeCodeList,
							@Parameter(name = "lat", description = "纬度", required = true)
							@RequestParam(name = "lat", required = false) String lat,
							@Parameter(name = "lon", description = "经度", required = true)
							@RequestParam(name = "lon", required = false) String lon,
							@Parameter(name = "distance", description = "距离", required = true)
							@RequestParam(name = "distance", required = false) String distance,
							@Parameter(name = "page", description = "页码", required = true, example = "1")
								@RequestParam(name = "page", defaultValue = "1") int page,
							@Parameter(name = "count", description = "每页条数", required = true, example = "10")
								@RequestParam(name = "count", defaultValue = "10") int count, @Parameter(name = "areaCode", description = "地区code", required = false)
							@RequestParam(name = "areaCode", required = false) String areaCode) {

		return safetyRiskEventInfoService.findListForMap(parentTypeCode, monitoringObjectTypeCodeList,lat,lon,distance,areaCode);
	}



	/**
	 * 统计当前预警，今日预警，全部预警数量
	 *
	 * @return
	 */
	@GetMapping("/statisticalEventPc")
	public R statisticalEventPc(@Parameter(name = "areaCode", description = "地区code", required = false)
							  @RequestParam(name = "areaCode", required = false) String areaCode) {
		return safetyRiskEventInfoService.statisticalEventPc(areaCode);
	}

	/**
	 * 风险来源下拉
	 *
	 * @return
	 */
	@GetMapping("/eventSourceTypeSelect")
	public R eventSourceTypeSelect() {
		return safetyRiskEventInfoService.eventSourceTypeSelect();
	}

}