package com.hncy.sjdz.base.controller;

import com.hncy.sjdz.base.models.entity.SjdzInterfaceInfo;
import com.hncy.sjdz.base.models.vo.InterfaceVO;
import com.hncy.sjdz.base.service.SjdzInterfaceInfoService;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.security.annotation.Inner;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 智慧城管数据底座接口
 *
 * @author zhaoting
 * @date 2024-12-03 10:53:33
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/sjdzInterfaceInfo" )
@Tag(description = "sjdzInterfaceInfo" , name = "智慧城管数据底座接口管理" )
public class SjdzInterfaceInfoController {

    private final  SjdzInterfaceInfoService sjdzInterfaceInfoService;

	/**
	 * 获得对接接口
	 * @param interfaceVO
	 * @return R
	 */
	@PostMapping(value = "getSjdzInfoData")
	@Operation(summary = "获得对接接口" )
	@Inner(value = false)
	public R getSjdzInfoData(@RequestBody InterfaceVO interfaceVO) {
		return sjdzInterfaceInfoService.getSjdzInfoData(interfaceVO);
	}

	//获得群众呼声的办理情况
	@PostMapping(value = "getMzhsData")
	@Operation(summary = "获得群众呼声的办理情况" )
	@Inner(value = false)
	public R getMzhsData(@RequestBody InterfaceVO interfaceVO) {
		return sjdzInterfaceInfoService.getMzhsData(interfaceVO);
	}

    /**
     * 通过id查询智慧城管数据底座接口
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询" , description = "通过id查询" )
    @GetMapping("/{id}" )
    public R getById(@PathVariable("id" ) String id) {
        return R.ok(sjdzInterfaceInfoService.getById(id));
    }

    /**
     * 新增智慧城管数据底座接口
     * @param sjdzInterfaceInfo 智慧城管数据底座接口
     * @return R
     */
    @Operation(summary = "新增智慧城管数据底座接口" , description = "新增智慧城管数据底座接口" )
    @PostMapping
    public R save(@RequestBody SjdzInterfaceInfo sjdzInterfaceInfo) {
        return R.ok(sjdzInterfaceInfoService.save(sjdzInterfaceInfo));
    }

    /**
     * 修改智慧城管数据底座接口
     * @param sjdzInterfaceInfo 智慧城管数据底座接口
     * @return R
     */
    @Operation(summary = "修改智慧城管数据底座接口" , description = "修改智慧城管数据底座接口" )
    @PutMapping
    public R updateById(@RequestBody SjdzInterfaceInfo sjdzInterfaceInfo) {
        return R.ok(sjdzInterfaceInfoService.updateById(sjdzInterfaceInfo));
    }



	/**
	 * 通过id删除
	 * @param id id列表
	 * @return R
	 */
	@Operation(summary = "通过id删除" , description = "通过id删除" )
	@PostMapping("removeById")
	public R removeById(String id) {
		return R.ok(sjdzInterfaceInfoService.removeById(id)).setMsg("删除成功");
	}

}