package com.hncy.sjdz.base.service.impl;


import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.hncy.sjdz.base.mapper.SafetyEventDealingRecordMapper;
import com.hncy.sjdz.base.mapper.SafetyMonitoringRecordInfoMapper;
import com.hncy.sjdz.base.mapper.SafetyRiskEventInfoMapper;
import com.hncy.sjdz.base.models.entity.SafetyEventDealingRecord;
import com.hncy.sjdz.base.models.entity.SafetyMonitoringRecordInfo;
import com.hncy.sjdz.base.models.entity.SafetyRiskEventInfo;
import com.hncy.sjdz.base.service.SafetyRiskEventInfoService;
import com.hncy.sjdz.base.util.cdEncryption.DataEncryptionUtil;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.mybatis.custom.CustomPage;
import com.hncy4cloud.hncy.common.mybatis.custom.HncyPageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author cp
 * @since 2024-11-07 15:33:16
 */
@Service
@Slf4j
public class SafetyRiskEventInfoServiceImpl extends ServiceImpl<SafetyRiskEventInfoMapper, SafetyRiskEventInfo> implements SafetyRiskEventInfoService {

	@Autowired
	private SafetyRiskEventInfoMapper safetyRiskEventInfoMapper;
	@Autowired
	private SafetyEventDealingRecordMapper safetyEventDealingRecordMapper;

	@Autowired
	private SafetyMonitoringRecordInfoMapper safetyMonitoringRecordInfoMapper;


	@Value(value = "${picture.eventUrl}")
	private String pictureUrl;


	@Value(value = "${picture.eventZwwUrl}")
	private String pictureZwwUrl;
	@Autowired(required = false)
	private DataEncryptionUtil dataEncryptionUtil;

	@Override
	public R statisticalEvent(String parentTypeCode, String areaCode) {
		return R.ok(safetyRiskEventInfoMapper.statisticalEvent(parentTypeCode, areaCode));
	}


	@Override
	public R eventPage(String parentTypeCode, String riskLevelCode, String disposalStatus, String source, String areaCode, String dateType) {
		List<Map> list = safetyRiskEventInfoMapper.eventPage(parentTypeCode, riskLevelCode, disposalStatus, source, areaCode, dateType);
		CustomPage pageItem = HncyPageHelper.startManualPage(list);
		List<Map> items = pageItem.getItems();
		for (Map map : items) {
			if (map.get("encryption_status") != null) {
				if (map.get("encryption_status").equals("1")) {
					if (map.get("position") != null) {
						String position = dataEncryptionUtil.decryptSM4(map.get("position").toString());
						map.put("position", position);
					}
				}
			}

			if (map.get("photos") != null) {
				String eventPhotos = map.get("photos").toString();
				if (eventPhotos != null && eventPhotos != "") {
					String[] split = eventPhotos.split(",");
					String photo = pictureUrl + split[0];
					map.put("photos", photo);

					String photoZWW = pictureZwwUrl + split[0];
					map.put("photosZWW", photoZWW);

				}
			}
			//图片
//			List<SafetyEventDealingRecord> safetyEventDealingRecordList = safetyEventDealingRecordMapper.selectList(Wrappers.<SafetyEventDealingRecord>lambdaQuery()
//					.eq(SafetyEventDealingRecord::getRiskEventId, map.get("asriskId"))
//					.orderByAsc(SafetyEventDealingRecord::getCreateTime));
//			if (safetyEventDealingRecordList.size()>0){
//				String eventPhotos = safetyEventDealingRecordList.get(0).getEventPhotos();
//				if (eventPhotos!=null&&eventPhotos!=""){
//					String[] split = eventPhotos.split(",");
//					String photo = pictureUrl+ split[0];
//					map.put("photos",photo);
//				}
//
//			}

		}
		return R.ok(pageItem);
	}

	@Override
	public R getInfo(String riskId) {
		Map map = safetyRiskEventInfoMapper.getInfo(riskId);

		if (map != null) {
//			if (map.get("encryption_status")!=null){
//				if (map.get("encryption_status").equals("1")){
//					if (map.get("position")!=null){
//						String position = dataEncryptionUtil.decryptSM4(map.get("position").toString());
//						map.put("position",position);
//					}
//				}
//			}

			if (map.get("photos") != null) {
				String[] split = map.get("photos").toString().split(",");
				String photo = pictureUrl + split[0];
				map.put("photos", photo);

				String photoZWW = pictureZwwUrl + split[0];
				map.put("photosZWW", photoZWW);
			}
			List<SafetyEventDealingRecord> safetyEventDealingRecords = safetyEventDealingRecordMapper.selectList(Wrappers.<SafetyEventDealingRecord>lambdaQuery()
					.eq(SafetyEventDealingRecord::getRiskEventId, riskId)
					.orderByAsc(SafetyEventDealingRecord::getDealingTime));
			map.put("recordList", safetyEventDealingRecords);
			SafetyMonitoringRecordInfo safetyMonitoringRecordInfo = safetyMonitoringRecordInfoMapper.selectMonitoringValueById(riskId);
			if (safetyMonitoringRecordInfo != null) {
				map.put("monitoringProject", safetyMonitoringRecordInfo.getMonitoringProject());
				map.put("monitoringValue", safetyMonitoringRecordInfo.getMonitoringValue());
				List<SafetyMonitoringRecordInfo> list = safetyMonitoringRecordInfoMapper.selectList(Wrappers.<SafetyMonitoringRecordInfo>lambdaQuery()
						.eq(SafetyMonitoringRecordInfo::getMonitoringObjectId, safetyMonitoringRecordInfo.getMonitoringObjectId())
						.eq(SafetyMonitoringRecordInfo::getMonitoringProject, safetyMonitoringRecordInfo.getMonitoringProject())
						.eq(SafetyMonitoringRecordInfo::getReportObject, safetyMonitoringRecordInfo.getReportObject())
						.orderByDesc(SafetyMonitoringRecordInfo::getReportTime));
				if (list.size() > 0) {
					map.put("currentMonitoringValue", list.get(0).getMonitoringValue());
				}

			}

			//图片
			SafetyEventDealingRecord safetyEventDealingRecord = safetyEventDealingRecordMapper.selectOne(Wrappers.<SafetyEventDealingRecord>lambdaQuery()
					.eq(SafetyEventDealingRecord::getRiskEventId, map.get("asriskId"))
					.orderByAsc(SafetyEventDealingRecord::getCreateTime));
			if (safetyEventDealingRecord != null) {
				String eventPhotos = safetyEventDealingRecord.getEventPhotos();
				if (eventPhotos != null && eventPhotos != "") {
					String[] split = eventPhotos.split(",");
					String photo = pictureUrl + split[0];
					map.put("photos", photo);

					String photoZWW = pictureZwwUrl + split[0];
					map.put("photosZWW", photoZWW);
				}
			}
			return R.ok(map);
		}
		return R.ok();
	}

	@Override
	public R statisticalMonth(String areaCode) {
		Map map = new HashMap<>();
		List<Map> list = safetyRiskEventInfoMapper.statisticalMonth("一般风险", areaCode);
		map.put("ybLevelList", list);
		List<Map> redist = safetyRiskEventInfoMapper.statisticalMonth("红色风险", areaCode);
		map.put("redLevelList", redist);
		List<Map> yellowlist = safetyRiskEventInfoMapper.statisticalMonth("黄色风险", areaCode);
		map.put("yellowLevelList", yellowlist);
		List<Map> orangelist = safetyRiskEventInfoMapper.statisticalMonth("橙色风险", areaCode);
		map.put("orangeLevelList", orangelist);
		return R.ok(map);
	}

	@Override
	public R statisticalArea() {
		return R.ok(safetyRiskEventInfoMapper.statisticalArea());
	}

	@Override
	public R statisticalType(String type) {
		return R.ok(safetyRiskEventInfoMapper.statisticalType(type));
	}


	@Override
	public R findListForMap(String parentTypeCode, String monitoringObjectTypeCodeList, String lat, String lon, String distance, String areaCode) {
		String[] split = null;
		if (monitoringObjectTypeCodeList != null && !monitoringObjectTypeCodeList.equals("")) {
			split = monitoringObjectTypeCodeList.split(",");
		}
		List<Map> listForMap = safetyRiskEventInfoMapper.findListForMap(parentTypeCode, split, lat, lon, distance, areaCode);
		CustomPage pageItem = HncyPageHelper.startManualPage(listForMap);
		return R.ok(pageItem);

	}


	@Override
	public R statisticalEventPc(String areaCode) {
		Map resut = new HashMap<>();

		Map map = safetyRiskEventInfoMapper.statisticalEvent("", areaCode);
		resut.put("monthEventTotal", map.get("monthEventTotal"));

		Map todayMap = safetyRiskEventInfoMapper.statisticalEventToday("", areaCode);
		resut.put("todayEventTotal", todayMap.get("todayEventTotal"));

		Map sumMap = safetyRiskEventInfoMapper.statisticalEventSum("", areaCode);
		resut.put("historyEventTotal", sumMap.get("eventTotal"));

		return R.ok(resut);
	}

	@Override
	public R eventSourceTypeSelect() {
		return R.ok(safetyRiskEventInfoMapper.eventSourceTypeSelect());
	}
}