package com.hncy.sjdz.base.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.util.StringUtil;
import com.hncy.sjdz.base.models.entity.SjdzInterfaceInfo;
import com.hncy.sjdz.base.mapper.SjdzInterfaceInfoMapper;
import com.hncy.sjdz.base.models.vo.CallInformationVO;
import com.hncy.sjdz.base.models.vo.InterfaceVO;
import com.hncy.sjdz.base.models.vo.RecordQZData;
import com.hncy.sjdz.base.service.SjdzInterfaceInfoService;
import com.hncy.sjdz.base.util.UrlUtils;
import com.hncy.sjdz.util.JsonUtils;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.core.util.RedisUtils;
import com.troy.keeper.utils.SM4Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 智慧城管数据底座接口
 *
 * @author zhaoting
 * @date 2024-12-03 10:53:33
 */
@Service
@Slf4j
public class SjdzInterfaceInfoServiceImpl extends ServiceImpl<SjdzInterfaceInfoMapper, SjdzInterfaceInfo> implements SjdzInterfaceInfoService {

	@Override
	public R getSjdzInfoData(InterfaceVO interfaceVO) {
		String typeCode = interfaceVO.getTypeCode();
		if(StringUtil.isEmpty(typeCode)){
			return R.failed("接口类型不能为空");
		}else {
			List<SjdzInterfaceInfo> sjdzInterfaceInfos = baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery().eq(SjdzInterfaceInfo::getTypeCode, typeCode));
			if(sjdzInterfaceInfos.size()==0){
				return R.failed("未查询到该类型接口信息");
			}
			SjdzInterfaceInfo sjdzInterfaceInfo = sjdzInterfaceInfos.get(0);
			String isCache = sjdzInterfaceInfo.getIsCache();
			int i = interfaceVO.hashCode();
			//需要缓存
			if("1".equals(isCache)){
				Object o = RedisUtils.get("sjdz:" + i);
				if(o!=null){
					return R.ok(o);
				}
			}
			String interfaceAddress = sjdzInterfaceInfo.getInterfaceAddress();
			String method = sjdzInterfaceInfo.getMethod();
			String authUserName = sjdzInterfaceInfo.getAuthUserName();
			String authUserKey = sjdzInterfaceInfo.getAuthUserKey();
			String id = interfaceVO.getId();
			String url= interfaceAddress;
			if(StringUtil.isNotEmpty(id)){
				url=url+"/"+id;
			}
			Map<String, Object> params = interfaceVO.getParams();
			if(StringUtil.isNotEmpty(authUserName)){
				params.put("authUserName",authUserName);
			}
			if(StringUtil.isNotEmpty(authUserKey)){
				params.put("authUserKey",authUserKey);
			}
			if(params!=null){
				String s = UrlUtils.mapToUrlParams(params);
				url+="?"+s;
			}
			log.info("url:{}",url);
			HttpRequest request = HttpUtil.createRequest(cn.hutool.http.Method.valueOf(method), url);

			request.header("Content-Type","application/json");
			Map<String, Object> data = interfaceVO.getData();
			if(data!=null){
				String s = JsonUtils.toJson(data);
				request.body(s);
			}

			String result  = request.execute().body();
			log.info("result:{}",result);
			String isDecryption = sjdzInterfaceInfo.getIsDecryption();
			if("1".equals(isDecryption)){
				String privateKey = sjdzInterfaceInfo.getPrivateKey();
				try {
					result = SM4Util.decryptEcb(privateKey,result);
					JSONObject entries = JSONUtil.parseObj(result,false);
					if("1".equals(isCache)){
						RedisUtils.set("sjdz:" + i, entries,60*60*1);
					}
					return R.ok(entries);
				} catch (Exception e) {
					e.printStackTrace();
					return R.failed("获取数据失败");
				}
			}else {
				//不需要解密
				JSONObject entries = JSONUtil.parseObj(result,false);
				if("1".equals(isCache)){
					RedisUtils.set("sjdz:" + i, entries,60*60*1);
				}
				return R.ok(entries);
			}
		}


	}

	@Override
	public R getMzhsData(InterfaceVO interfaceVO) {
		Map map = new HashMap();
		List<String> mzhsCodesDates =new ArrayList<>();
		mzhsCodesDates.add("zzcc-quajNum");
		mzhsCodesDates.add("zzcc-cqajNum");
		mzhsCodesDates.add("zzcc-12345blz");
		List<SjdzInterfaceInfo> sjdzInterfaceInfos =
				baseMapper.selectList(Wrappers.<SjdzInterfaceInfo>lambdaQuery()
				.in(SjdzInterfaceInfo::getTypeCode, mzhsCodesDates));
		log.info("sjdzInterfaceInfos:{}",sjdzInterfaceInfos);
		Map<String, Object> params = interfaceVO.getParams();
		interfaceVO.setParams(params);
		for(SjdzInterfaceInfo sjdzInterfaceInfo : sjdzInterfaceInfos){
			interfaceVO.setTypeCode(sjdzInterfaceInfo.getTypeCode());
			R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
			if(sjdzInfoData.isSuccess()) {
				Map data = (Map) sjdzInfoData.getData();
				Map data1 = (Map)data.get("data");
				Object records1 = data1.get("records");
				JSONArray jsonArray = JSONUtil.parseArray(records1);
				List<RecordQZData> records = jsonArray.toList(RecordQZData.class);
				log.info("records:{}"+sjdzInterfaceInfo.getTypeCode(),records);
				if("zzcc-quajNum".equals(sjdzInterfaceInfo.getTypeCode())) {
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("slNum",sum);
					}else {
						map.put("slNum",0);
					}
				}else if("zzcc-cqajNum".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("cqNum",sum);
					}else {
						map.put("cqNum",0);
					}

				}else if("zzcc-12345blz".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("blNum",sum);
					}else {
						map.put("blNum",0);
					}
				}
			}
		}
		LocalDate currentDate = LocalDate.now();
		DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
		String time = currentDate.format(formatter);
		params.put("startTime",time);
		params.put("endTime",time);
		interfaceVO.setParams(params);
		//今日
		for(SjdzInterfaceInfo sjdzInterfaceInfo : sjdzInterfaceInfos){
			interfaceVO.setTypeCode(sjdzInterfaceInfo.getTypeCode());
			R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
			if(sjdzInfoData.isSuccess()) {
				Map data = (Map) sjdzInfoData.getData();
				Map data1 = (Map)data.get("data");
				Object records1 = data1.get("records");
				JSONArray jsonArray = JSONUtil.parseArray(records1);
				List<RecordQZData> records = jsonArray.toList(RecordQZData.class);
				log.info("records:{}"+sjdzInterfaceInfo.getTypeCode(),records);
				if("zzcc-quajNum".equals(sjdzInterfaceInfo.getTypeCode())) {
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("slNumDay",sum);
					}else {
						map.put("slNumDay",0);
					}
				}else if("zzcc-cqajNum".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("cqNumDay",sum);
					}else {
						map.put("cqNumDay",0);
					}

				}else if("zzcc-12345blz".equals(sjdzInterfaceInfo.getTypeCode())){
					if(records!=null){
						int sum = records.stream().mapToInt(recordQZData -> recordQZData.getNum()).sum();
						map.put("blNumDay",sum);
					}else {
						map.put("blNumDay",0);
					}
				}
			}
		}
		return R.ok(map);
	}

	@Override
	public R getCallInformationInfoById(String id) {
		InterfaceVO interfaceVO = new InterfaceVO();
		interfaceVO.setTypeCode("12345-tsgdlb");
		Map<String,Object> datadd=new HashMap<>();
		datadd.put("sczj",id);
		interfaceVO.setData(datadd);
		R sjdzInfoData = this.getSjdzInfoData(interfaceVO);
		if(sjdzInfoData.isSuccess()){
			Map data = (Map) sjdzInfoData.getData();
			Map data1 = (Map)data.get("data");
			Object records1 = data1.get("records");
			JSONArray jsonArray = JSONUtil.parseArray(records1);
			List<Map> records = jsonArray.toList(Map.class);
			if(records!=null && records.size()>0){
				Map map = records.get(0);
				CallInformationVO callInformationVO = new CallInformationVO();
				callInformationVO.setOtherInfo(map);
				Object sczj = map.get("sczj");
				if(sczj!=null){
					callInformationVO.setId(sczj.toString());
				}
				Object bt = map.get("bt");
				if(bt!=null){
					callInformationVO.setTitle(bt.toString());
				}
				Object ldlx = map.get("ldlx");
				if(ldlx!=null){
					callInformationVO.setCallType(ldlx.toString());
				}
				Object lxrmc = map.get("lxrmc");
				if(lxrmc!=null){
					callInformationVO.setSenderName(lxrmc.toString());
				}
				Object ly = map.get("ly");
				if(ly!=null){
					callInformationVO.setSource(ly.toString());
				}else {
					Object lx = map.get("lx");
					callInformationVO.setSource(lx.toString());
				}
				Object ldxnr = map.get("ldxnr");
				if(ldxnr!=null){
					callInformationVO.setCallContent(ldxnr.toString());
				}
				Object bldw = map.get("bldw");
				if(bldw!=null){
					if("-1".equals(bldw.toString())){
						callInformationVO.setHandlingUnit("");
					}else {
						callInformationVO.setHandlingUnit(bldw.toString());
					}
				}
				Object blzt = map.get("blzt");
				if(blzt!=null){
					callInformationVO.setHandlingStatus(blzt.toString());
				}
				Object ssqy = map.get("ssqy");
				if(ssqy!=null){
					callInformationVO.setArea(ssqy.toString());
				}
				Object ldxsj = map.get("ldxsj");
				if(ldxsj!=null){
					callInformationVO.setReportTime(ldxsj.toString());
				}
				if(map.get("hfsj")!=null){
					callInformationVO.setProcessingTime(map.get("hfsj").toString());
				}
				if(map.get("hfnr")!=null){
					callInformationVO.setProcessingContent(map.get("hfnr").toString());
				}
				return R.ok(callInformationVO);
			}else {
				return R.failed("获取数据失败");
			}
		}else {
			return R.failed("获取数据失败");
		}
	}
}