package com.hncy.sjdz.base.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hncy.sjdz.base.models.entity.SjdzMajorProject;
import com.hncy.sjdz.base.models.vo.MajorProjectYearStatisticsVO;
import com.hncy.sjdz.base.models.vo.SjdzMajorProjectListVO;
import com.hncy.sjdz.base.models.vo.SjdzMajorProjectVO;
import com.hncy.sjdz.base.service.SjdzMajorProjectService;
import com.hncy.sjdz.base.mapper.SjdzMajorProjectMapper;
import com.hncy4cloud.hncy.common.core.util.R;
import com.hncy4cloud.hncy.common.mybatis.custom.CustomPage;
import com.hncy4cloud.hncy.common.mybatis.custom.HncyPageHelper;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.Year;
import java.time.temporal.TemporalAdjusters;
import java.util.List;
import java.util.stream.Collectors;

/**
* @author tyz
* @description 针对表【sjdz_major_project(数据底座-重大项目信息)】的数据库操作Service实现
* @createDate 2024-11-12 15:36:57
*/
@Service
public class SjdzMajorProjectServiceImpl extends ServiceImpl<SjdzMajorProjectMapper, SjdzMajorProject>
    implements SjdzMajorProjectService{

    @Override
    public R pageList(String searchText) {
		LocalDate startOfYear = LocalDate.now().with(TemporalAdjusters.firstDayOfYear());
		LocalDate endOfYear = LocalDate.now().with(TemporalAdjusters.lastDayOfYear());
		LambdaQueryWrapper<SjdzMajorProject> lambdaQueryWrapper = new LambdaQueryWrapper<>();
		lambdaQueryWrapper.between(SjdzMajorProject::getStartDate, startOfYear, endOfYear);
		lambdaQueryWrapper.orderByDesc(SjdzMajorProject::getCreateTime);
		if (StrUtil.isNotBlank(searchText)){
			lambdaQueryWrapper.like(SjdzMajorProject::getProjectName, searchText);
		}
		lambdaQueryWrapper.last("limit 10");
		List<SjdzMajorProject> sjdzMajorProjects = this.list(lambdaQueryWrapper);

		List<SjdzMajorProjectListVO> convertedPage = sjdzMajorProjects.stream().map (entity -> {
			SjdzMajorProjectListVO sjdzMajorProjectListVO = new SjdzMajorProjectListVO();
			sjdzMajorProjectListVO.setId(entity.getId());
			sjdzMajorProjectListVO.setProjectName(entity.getProjectName());
			sjdzMajorProjectListVO.setUnitName(entity.getUnitName());
			String dateRange = "";
			if (entity.getStartDate() != null) {
				dateRange = LocalDateTimeUtil.format(entity.getStartDate(), "yyyy-MM-dd");
			}
			if (entity.getEndDate() != null) {
				dateRange =dateRange+ "~" + LocalDateTimeUtil.format(entity.getEndDate(), "yyyy-MM-dd");
			}
			sjdzMajorProjectListVO.setDateRange(dateRange);
			return sjdzMajorProjectListVO;
		}).collect(Collectors.toList());
		return R.ok(convertedPage);
    }

	@Override
	public R getThisYearMajorProject() {
		List<MajorProjectYearStatisticsVO> thisYearMajorProject = baseMapper.getThisYearMajorProject();
		return R.ok(thisYearMajorProject);
	}

	@Override
	public SjdzMajorProjectVO getProjectInfo(String projectId) {
		SjdzMajorProject sjdzMajorProject = this.getById(projectId);
		SjdzMajorProjectVO sjdzMajorProjectVO = new SjdzMajorProjectVO();
		BeanUtil.copyProperties(sjdzMajorProject, sjdzMajorProjectVO);
		return sjdzMajorProjectVO;
	}
}




